<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt </source>
        <translation>usando le librerie QT </translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>Grazie a</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>E&apos; un applicazione  leggera ma potente, scritto in Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website</source>
        <translation>Sito Web</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="109"/>
        <source>Licensed under the </source>
        <translation>Rilasciato sotto licenza </translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>Contribuisci</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translatorcomment>copyright updated to 2015, ok?</translatorcomment>
        <translation>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>Cosa puoi fare?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>è una applicazione per catturare velocemente schermate per tutte le piattaforme.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Se ti piace questa applicazione puoi contribuire.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Puoi tradurre ScreenGrab in altre lingue</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>Fai proposte per le prossime versioni</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>Segnala problemi e bug</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>Segnala bug</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="141"/>
        <source>Translate:</source>
        <translation>Traduzioni:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source> Brazilian Portuguese translation</source>
        <translation> ·Traduzioni in Portoghese Brasiliano</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>Marcio Moraes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source> Ukrainian translation</source>
        <translation> ·Traduzioni in Ucraino</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="147"/>
        <source>Gennadi Motsyo</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source> Spanish translation</source>
        <translation> ·Spanish translation</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="150"/>
        <source>Burjans L García D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="152"/>
        <source> Italian translation</source>
        <translation> Traduziona italiana</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="156"/>
        <source>Testing:</source>
        <translation>Test:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>Supporto per due monitor e altro in Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>Dual monitor support in Linux</source>
        <translation>Supporto dual monitor in Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>win32-build [Windows XP and 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>win32-build vecchio [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="162"/>
        <source>win32-build [Windows 7]</source>
        <translation>win32-build [Windows 7]</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="300"/>
        <source>Select directory</source>
        <translation>Selezionare la cartella</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="211"/>
        <location filename="../src/core/ui/configwidget.cpp" line="312"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="210"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>La cartella %1 non esiste. Vuoi crearla?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="311"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Vuoi ripristinare la configurazione iniziale?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="369"/>
        <source>Example: </source>
        <translation>Esempio: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="425"/>
        <source>This key is already used in your system! Please select another.</source>
        <translation>Questa scorciatoia è già in uso. Seleziona un altra per favore.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="431"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>Questa scorciatoia è già usata in ScreenGrab. Seleziona un altra.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="449"/>
        <source>This key is not supported on your system!</source>
        <translation>Questa chiave non è supportata dal tuo sistema!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="484"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="422"/>
        <source>Saved</source>
        <translation>Salvata</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="444"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Il nome del file salvato è stato copiato negli appunti</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="472"/>
        <source>Copied</source>
        <translation>Copiata</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="422"/>
        <source>Saved to </source>
        <translation>Salvata in </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="63"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>è una applicazione per catturare velocemente schermate per tutte le piattaforme.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="67"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Cattura lo schermo intero</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="71"/>
        <source>Take a screenshot of the active window</source>
        <translation>Cattura la finestra attiva</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="75"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Cattura una selezione dello schermo</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="79"/>
        <source>Run the application with a hidden main window</source>
        <translation>Avvia l&apos;&apos;applicazione con la finestra principale nascosta</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="450"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>Il percorso del file salvato è stato copiato negli appunti</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="472"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>La schermata è stata copiata negli appunti</translation>
    </message>
</context>
<context>
    <name>DialogUploader</name>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="14"/>
        <source>Upload to internet</source>
        <translation>Carica in rete</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="22"/>
        <source>Upload to</source>
        <translation>Carica a</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="76"/>
        <source>Direct link:</source>
        <translation>Collegamento diretto:</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="98"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="189"/>
        <source>Open this link in the default web-browser</source>
        <translation>Apri questo link con il browser predefinito</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="101"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="192"/>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="114"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="155"/>
        <source>Copy this link to the clipboard</source>
        <translation>Copia questo link agli appunti</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="117"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="158"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="128"/>
        <source>Extended preformed html or bb codes:</source>
        <translation>Codici html o bb preformati estesi:</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="167"/>
        <source>Link to delete image:</source>
        <translation>Indirizzo per rimuovere immagine:</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="300"/>
        <source>Upload</source>
        <translation>Carica</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="313"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="58"/>
        <source>Size: </source>
        <translation>Grandezza: </translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="58"/>
        <source> pixel</source>
        <translation> pixel</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="68"/>
        <source>Uploaded </source>
        <translation>Caricato </translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="71"/>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="212"/>
        <source>Ready to upload</source>
        <translation>Pronto a caricare</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="108"/>
        <source>Upload processing... Please wait</source>
        <translation>Caricamento in corso... Attendere</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="160"/>
        <source>Receiving a response from the server</source>
        <translation>Ricevendo una risposta dal server</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="177"/>
        <source>Upload completed</source>
        <translation>Caricamento completato</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="199"/>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="214"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="206"/>
        <source>Error uploading screenshot</source>
        <translation>Errore durante il caricamento dello screenshot</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="207"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="244"/>
        <source>Open this link in your default web-browser, it may directly delete your uploaded image, without any warnings.</source>
        <translation>Apre questo link con il tuo browser predefinito, potrebbe direttamente rimuovere la tua immagine caricata, senza alcun avvertimento.</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="245"/>
        <source>Are you sure you want to continue?</source>
        <translation>Sei sicuro di voler continuare?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation>ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>Tipo di cattura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>Area dello schermo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation>Ultima area selezionata</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation>Ritardo:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation>Ingrandisce area intorno al cursore</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation>Escludi le decorazioni delle finestre</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation>Cattura cursore</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Ritardo in secondi prima di effettuare la cattura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> ·sec</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="67"/>
        <source>Options</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="68"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="92"/>
        <source>Help</source>
        <translation>Guida</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="70"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="65"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="64"/>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="66"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="369"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Doppio clic per aprire la cattura in un editor esterno</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="378"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="509"/>
        <source>Hide</source>
        <translation>Nascondi</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="569"/>
        <source>%1 Files</source>
        <translation>%1 File</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="69"/>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="365"/>
        <source>Screenshot </source>
        <translation>Schermata </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="516"/>
        <source>Show</source>
        <translation>Mostra</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="591"/>
        <source>Save As...</source>
        <translation>Salva con nome...</translation>
    </message>
</context>
<context>
    <name>ModuleUploader</name>
    <message>
        <location filename="../src/modules/uploader/moduleuploader.cpp" line="41"/>
        <source>Upload the screenshot to the default image host</source>
        <translation>Carica lo screenshot al host predefinito</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/moduleuploader.cpp" line="48"/>
        <source>Uploading</source>
        <translation>Caricando</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="160"/>
        <source>Use your mouse to draw a rectangle to screenshot or exit pressing
any key or using the right or middle mouse buttons.</source>
        <translation>Usa il mouse per delineare un rettangolo da catturare o esci premendo
un tasto qualsiasi o usando il tasto destro o centrale del mouse.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="192"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 pixel </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Editor esterno</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Modifica con...</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/moduleuploader.cpp" line="103"/>
        <source>Upload</source>
        <translation>Carica</translation>
    </message>
</context>
<context>
    <name>Uploader</name>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="225"/>
        <source>Direct link</source>
        <translation>Link diretto</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="228"/>
        <source>HTML code</source>
        <translation>Codice HTML</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="231"/>
        <source>BB code</source>
        <translation>Codice BB</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="234"/>
        <source>HTML code with thumb image</source>
        <translation>Codice HTML con la miniatura</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="237"/>
        <source>BB code with thumb image</source>
        <translation>Codice BB con la miniatura</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="240"/>
        <source>URl to delete image</source>
        <translation>URl per eliminare l&apos;immagine</translation>
    </message>
</context>
<context>
    <name>UploaderConfigWidget</name>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="24"/>
        <source>Common settings</source>
        <translation>Impostazioni comuni</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="32"/>
        <source>Default image host</source>
        <translation>Host per le immagini predefinito</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="44"/>
        <source>Always copy the link to the clipboard</source>
        <translation>Copia sempre il link negli appunti</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="65"/>
        <source>Hosts settings</source>
        <translation>Impostazioni Host</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="73"/>
        <source>Settings for: </source>
        <translation>Impostazioni per: </translation>
    </message>
</context>
<context>
    <name>UploaderConfigWidget_ImgUr</name>
    <message>
        <location filename="../src/modules/uploader/imgur/uploaderconfigwidget_imgur.ui" line="20"/>
        <source>Configuration for imgur.com upload</source>
        <translation>Configurazioni per il caricamento su imgur.com</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/imgur/uploaderconfigwidget_imgur.ui" line="43"/>
        <source>No settings available right now</source>
        <translation>Nessuna impostazione disponibile al momento</translation>
    </message>
</context>
<context>
    <name>Uploader_ImgUr_Widget</name>
    <message>
        <location filename="../src/modules/uploader/imgur/uploader_imgur_widget.ui" line="20"/>
        <source>Upload to Imgur</source>
        <translation>Carica su Imgur</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="128"/>
        <source>About Qt</source>
        <translation>Informazioni su QT</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="154"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="627"/>
        <source>Options</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>Formato standard di salvataggio immagine</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Inserisci la data e l&apos;orario corrente nel nome file</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation>Inserisci data e ora nel nome del file</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>Salva la cattura automaticamente</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>Salva la prima cattura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>Qualità imagine</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Qualità immagine (1 -bassa, 100 massima qualità)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Permetti istanze multiple di ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>Abilita visualizzatore esterno</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>Fit to edges only inside selected screen area</source>
        <translatorcomment>Looks like not present in GUI</translatorcomment>
        <translation>Adatta ai bordi all&apos;interno della selezione</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="410"/>
        <source>Fit to edges inside selected area</source>
        <translation>Adatta a bordi all&apos;interno della selezione</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="448"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Mostra ScreenGrab nel vassoio di sistema</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="533"/>
        <source>Minimize to tray on click close button</source>
        <translation>Minimizza nel vassoio di sistema cliccando il pulsante chiudi</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="536"/>
        <source>Minimize to tray when closing</source>
        <translation>Minimizza nel vassoio alla chiusura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="575"/>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="585"/>
        <source>Global shortcuts</source>
        <translation>Scorciatoie globali</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="597"/>
        <source>Active window</source>
        <translation>Finestra attiva</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="602"/>
        <source>Area select</source>
        <translation>Selezione area</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="608"/>
        <source>Local shortcuts</source>
        <translation>Scorciatoie locali</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="612"/>
        <source>New screen</source>
        <translation>Nuova cattura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="617"/>
        <source>Save screen</source>
        <translation>Salva cattura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="622"/>
        <source>Copy screen</source>
        <translation>Copia cattura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="632"/>
        <source>Help</source>
        <translation>Guida</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="655"/>
        <source>Not defined</source>
        <translation>Non definito</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation>Vassoio</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation>Percorso per i salvataggi predefinito</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>Sfoglia le cartelle</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>Sfoglia</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>Nome file predefinito</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Copia nome del file negli appunti quando salvi</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation>Non copiare</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation>Copia solo il nome del file</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation>Copia il percorso completo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="515"/>
        <source> sec</source>
        <translation> ·sec</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation>Cartella di salvataggio predefinita</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation>File predefinito</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>Modello: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>Esempio: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Salva la schermata automaticamente durante la cattura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="457"/>
        <source>Tray messages:</source>
        <translation>Messaggi nell&apos;area di notifica:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="470"/>
        <source>Tray messages display mode</source>
        <translation>Modalità di visualizzazione nell&apos;area di notifica</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="474"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="479"/>
        <source>Tray mode</source>
        <translation>Modalità area di notifica</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="484"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="496"/>
        <source>Time of display tray messages</source>
        <translation>Tempo di esposizione dei messaggi</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="512"/>
        <source>Time to display tray messages</source>
        <translation>Tempo di esposizione dei messaggi nell&apos;area di notifica</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Permetti istanze multiple di ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation>Apri la cattura in un visualizzatore esterno con doppio clic</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="580"/>
        <source>Shortcut</source>
        <translation>Scorciatoia</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="592"/>
        <source>Full screen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="637"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="648"/>
        <source>Selected shortcut:</source>
        <translation>Seleziona scorciatoia:</translation>
    </message>
</context>
</TS>
